## Variant effect scores

- [ ] describe how these relate to the yaml file

## Available scores

<span style="float:right;">[[source]](https://github.com/kipoi/kipoi/blob/master/kipoi/postprocessing/variant_effects/utils/scoring_fns.py#L49)</span>
### Logit

```python
kipoi.postprocessing.variant_effects.utils.scoring_fns.Logit(rc_merging='mean')
```

----

<span style="float:right;">[[source]](https://github.com/kipoi/kipoi/blob/master/kipoi/postprocessing/variant_effects/utils/scoring_fns.py#L63)</span>
### LogitAlt

```python
kipoi.postprocessing.variant_effects.utils.scoring_fns.LogitAlt(rc_merging='mean')
```

----

<span style="float:right;">[[source]](https://github.com/kipoi/kipoi/blob/master/kipoi/postprocessing/variant_effects/utils/scoring_fns.py#L77)</span>
### LogitRef

```python
kipoi.postprocessing.variant_effects.utils.scoring_fns.LogitRef(rc_merging='mean')
```

----

<span style="float:right;">[[source]](https://github.com/kipoi/kipoi/blob/master/kipoi/postprocessing/variant_effects/utils/scoring_fns.py#L77)</span>
### LogitRef

```python
kipoi.postprocessing.variant_effects.utils.scoring_fns.LogitRef(rc_merging='mean')
```

----

<span style="float:right;">[[source]](https://github.com/kipoi/kipoi/blob/master/kipoi/postprocessing/variant_effects/utils/scoring_fns.py#L106)</span>
### Diff

```python
kipoi.postprocessing.variant_effects.utils.scoring_fns.Diff(rc_merging='mean')
```

----

<span style="float:right;">[[source]](https://github.com/kipoi/kipoi/blob/master/kipoi/postprocessing/variant_effects/utils/scoring_fns.py#L118)</span>
### DeepSEA_effect

```python
kipoi.postprocessing.variant_effects.utils.scoring_fns.DeepSEA_effect(rc_merging='mean')
```

